# bioDAG

This is a package to preprocess DAG-structure biological data. Now, it supports
* [MeSH](https://www.ncbi.nlm.nih.gov/mesh)

## MeSH
There are some contents to introduce workflow and functions for MeSH